LSST Comet
==========

Calculating the coma magnitude of a comet with input specifications. We have :ref:`notebooks`  demonstrating the LSSTCometActivity class built into ``Sorcha add-ons``.  To use this prescription the **comet_activity** :ref:`configuration file<configs>` variable should be set to **lsst_comet**.


Using code derived from ``lsstcomet`` by Mike Kelley
(C)  LSST Solar System Scientific Collaboration 2019
